@@ -1,10 +1,10 @@
-from .linguistics import Tokenize, Snowball, Phrase
+from .linguistics import Tokenize, Snowball, Phrase, Sub
 from .embedding import TfIdf, Count, Embedding, OneHot
 from .reduction import SVD, PCA, NMF, UMAP
 from .classifier import RandomForest, AdaBoost, SVM, MLP, Keras
 
 __all__ = [
-    "Tokenize", "Snowball", "Phrase",
+    "Tokenize", "Snowball", "Phrase", "Sub",
     "TfIdf", "Count", "Embedding", "OneHot",
     "SVD", "PCA", "NMF", "UMAP",
     "RandomForest", "AdaBoost", "SVM", "MLP", "Keras"
